==========================
 Invenio-Access v1.0.0a12
==========================

Invenio-Access v1.0.0a12 was released on May 05, 2017.

About
-----

Invenio module for common role based access control.

*This is an experimental developer preview release.*

Installation
------------

   $ pip install invenio-access==1.0.0a12

Documentation
-------------

   https://invenio-access.readthedocs.io

Happy hacking and thanks for flying Invenio-Access.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-access
|   URL: http://inveniosoftware.org
